translate.storage.versioncontrol.bzr.bzr

Package translate :: Package storage :: Package versioncontrol :: Module bzr :: Class bzr |
[hide private]
[frames] | no frames]

# Class bzr

source code

Class to manage items under revision control of bzr.

Instance Methods | [hide private]
update(self, revision=None) Does a clean update of the given path | source code
commit(self, message=None, author=None) Commits the file and supplies the given commit message if present | source code
getcleanfile(self, revision=None) Get a clean version of a file from the bzr repository | source code
Inherited from `GenericRevisionControlSystem`: `__init__` Inherited from `GenericRevisionControlSystem` (private): `_find_rcs_directory`, `_find_rcs_in_parent_directories`, `_self_check`

Class Variables | [hide private]
| RCS_METADIR = ``'``.bzr``'`` The name of the metadata directory of the RCS
| SCAN_PARENTS = `True` whether to check the parent directories for the metadata directory of the RCS working copy

Method Details | [hide private]

### update(self, revision=None) | source code
Does a clean update of the given path Overrides: GenericRevisionControlSystem.update

### commit(self, message=None, author=None) | source code
Commits the file and supplies the given commit message if present Overrides: GenericRevisionControlSystem.commit

### getcleanfile(self, revision=None) | source code
Get a clean version of a file from the bzr repository Overrides: GenericRevisionControlSystem.getcleanfile